//!OpenSCAD

Width = 8.25; 
Depth = 2.625; 
Height = 0.625; 
Units = 25.4; // [1:Millimeters, 25.4:Inches] 
Number_of_Rows = 2; 
Number_of_Columns = 3; 
Large_Compartment = "Depth-wise"; // [Width-wise, Depth-wise, None] 
Corner_Radius = 0.25; 
Lid_Proportion = 40; 
Stock_Thickness = 0.5625; 
Endmill_Diameter = 0.125; 
my_3D_Preview = false; 
$fn=80;

w = Width * Units;
d = Depth * Units;
h = Height * Units;
ed = Endmill_Diameter * Units;
st = Stock_Thickness * Units;
cr = Corner_Radius * Units;
crhalf = cr / 2;
xwidth = w - cr * 2;
ydepth = d - cr * 2;
xcell = (xwidth - (Number_of_Columns - 1) * crhalf) / Number_of_Columns;
ycell = (ydepth - (Number_of_Rows - 1) * crhalf) / Number_of_Rows;

module Make_Bottom() {
  difference() {
    union(){
      Cut_Pocket(0, 0, 0, w, d, st * ((100 - Lid_Proportion) / 100), cr);
      translate([0, 0, (st * ((Lid_Proportion / 2) / 100))]){
        Cut_Pocket(crhalf, crhalf, 0, w - cr, d - cr, st * ((100 - Lid_Proportion) / 100), (cr * 3) / 4);
      }
    }

    translate([cr, cr, (st * ((Lid_Proportion / 2) / 100))]){
      if (Number_of_Columns == 1 && Number_of_Rows == 1) {
        Cut_Pocket(0, 0, 0, xwidth, ydepth, st, crhalf);
      } else {
        union(){
          for (i = [0 : abs(1) : Number_of_Columns - 1]) {
            for (j = [0 : abs(1) : Number_of_Rows - 1]) {
              Cut_Pocket(i * (xcell + crhalf), j * (ycell + crhalf), 0, xcell, ycell, st, crhalf);
            }

          }

          if (Large_Compartment == "Width-wise") {
            Cut_Pocket(0, 0, 0, xwidth, ycell, st, crhalf);
          } else if (Number_of_Columns > 1 && Large_Compartment == "Depth-wise") {
            if (Number_of_Columns % 2 == 0) {
              Cut_Pocket(0, 0, 0, xcell, ydepth, st, crhalf);
            } else if (Number_of_Columns % 2 == 1) {
              Cut_Pocket(ceil((Number_of_Columns - 1) / 2) * (xcell + crhalf), 0, 0, xcell, ydepth, st, crhalf);
            }

          }

        }
      }

    }
  }
}

module Cut_Pocket(xorigin, yorigin, zorigin, pocketwidth, pocketdepth, pocketheight, cornerradius) {
  translate([0, 0, (-pocketheight)]){
    hull(){
      translate([(xorigin + cornerradius), (yorigin + cornerradius), (zorigin + pocketheight)]){
        cylinder(r1=cornerradius, r2=cornerradius, h=(pocketheight * 1.01), center=false);
      }
      translate([((xorigin - cornerradius) + pocketwidth), (yorigin + cornerradius), (zorigin + pocketheight)]){
        cylinder(r1=cornerradius, r2=cornerradius, h=(pocketheight * 1.01), center=false);
      }
      translate([(xorigin + cornerradius), ((yorigin - cornerradius) + pocketdepth), (zorigin + pocketheight)]){
        cylinder(r1=cornerradius, r2=cornerradius, h=(pocketheight * 1.01), center=false);
      }
      translate([((xorigin - cornerradius) + pocketwidth), ((yorigin - cornerradius) + pocketdepth), (zorigin + pocketheight)]){
        cylinder(r1=cornerradius, r2=cornerradius, h=(pocketheight * 1.01), center=false);
      }
    }
  }
}

module Make_Top() {
  difference() {
    Cut_Pocket(0, 0, 0, w, d, st * (Lid_Proportion / 100), cr);

translate ([0,0,st * ((Lid_Proportion / 2) / 100)]){
    Cut_Interior();
}
  }
}

module Cut_Interior() {
  Cut_Pocket(crhalf, crhalf, 0, w - cr, d - cr, st, (cr * 3) / 4);
}

if (my_3D_Preview == true) {
  union(){
    Make_Bottom();
    translate([(w + ed * 1.1), 0, 0]){
      Make_Top();
    }
  }
} else {
projection() {
  difference() {
    Cut_Pocket(-(ed * 1.1), -(ed * 1.1), 0, w * 2 + (ed * 1.1) * 3, d + (ed * 1.1) * 2, 0.01, ed * 1.1);

    translate([0, 0, (-0.01)]){
      difference() {
        Make_Bottom();

        translate([0, 0, (-(st * ((100 - Lid_Proportion*0.9) / 100)))]){
          Make_Bottom();
        }
      }
      translate([(w + ed * 1.1), 0, 0]){
        difference() {
          Make_Top();

          translate([0, 0, 0]){
            Cut_Interior();
          }
        }
      }
    }
  }
}
}